nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Sts13

Struct Sts13 

#[repr(transparent)]
pub struct Sts13(pub u32);
Status Register 13

Tuple Fields

0: u32

Implementations

Source

impl Sts13

pub const fn slvlock(&self) -> Slvlock

Sample clock slave delay line locked.

pub const fn set_slvlock(&mut self, val: Slvlock)

Sample clock slave delay line locked.

pub const fn reflock(&self) -> Reflock

Sample clock reference delay line locked.

pub const fn set_reflock(&mut self, val: Reflock)

Sample clock reference delay line locked.

pub const fn slvsel(&self) -> u8

Sample clock slave delay line delay cell number selection.

pub const fn set_slvsel(&mut self, val: u8)

Sample clock slave delay line delay cell number selection.

pub const fn refsel(&self) -> u8

Sample clock reference delay line delay cell number selection.

pub const fn set_refsel(&mut self, val: u8)

Sample clock reference delay line delay cell number selection.