#[repr(transparent)]pub struct Sts13(pub u32);Expand description
Status Register 13
Tuple Fields
0: u32Implementations
Sourceimpl Sts13
impl Sts13
Sourcepub const fn set_slvlock(&mut self, val: Slvlock)
pub const fn set_slvlock(&mut self, val: Slvlock)
Sample clock slave delay line locked.
Sourcepub const fn set_reflock(&mut self, val: Reflock)
pub const fn set_reflock(&mut self, val: Reflock)
Sample clock reference delay line locked.
Sourcepub const fn set_slvsel(&mut self, val: u8)
pub const fn set_slvsel(&mut self, val: u8)
Sample clock slave delay line delay cell number selection.
Sourcepub const fn refsel(&self) -> u8
pub const fn refsel(&self) -> u8
Sample clock reference delay line delay cell number selection.
Sourcepub const fn set_refsel(&mut self, val: u8)
pub const fn set_refsel(&mut self, val: u8)
Sample clock reference delay line delay cell number selection.